# Util #

**Util** is a (tentative) **UG4-Plugin** providing functionality originally expressed in *_util.lua.

test

Copyright 2024 Goethe University Frankfurt

Replacements (tentative):

* ugcore/scripts/util/domain_util.lua

Please install/clone this repository through UG4's package manager
[ughub](https://github.com/UG4/ughub).
